@@ -1,35 +1,45 @@
 use anyhow::bail;
 
 use crate::{
-    client::{join_errors, Client},
+    client::client::{join_errors, Client},
     model::{
         expenses::{
-            CreateExpenseRequest, Expense, ExpenseWrapper, ExpensesWrapper, GetExpensesRequest,
+            CreateExpenseRequest, Expense, ExpenseWrapper, ExpensesWrapper, ListExpensesRequest,
             UpdateExpenseRequest,
         },
-        Success,
+        shared::Success,
     },
 };
 
+/// Expenses.
+///
+/// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses)
 #[derive(Debug)]
 pub struct ExpensesSvc<'c> {
     client: &'c Client,
 }
 
 impl<'c> ExpensesSvc<'c> {
+    /// Creates an instance of `ExpensesSvc`.
     pub fn new(client: &'c Client) -> Self {
         Self { client }
     }
 
+    /// Get expense information.
+    ///
+    /// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses/paths/~1get_expense~1{id}/get)
     pub async fn get_expense(&self, id: i64) -> Result<Expense, anyhow::Error> {
         let url = self.client.base_url.join(&format!("get_expense/{}", id))?;
         let response: ExpenseWrapper = self.client.get(url).await?;
         Ok(response.expense)
     }
 
-    pub async fn get_expenses(
+    /// List the current user's expenses.
+    ///
+    /// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses/paths/~1get_expenses/get)
+    pub async fn list_expenses(
         &self,
-        request: GetExpensesRequest,
+        request: ListExpensesRequest,
     ) -> Result<Vec<Expense>, anyhow::Error> {
         let mut url = self.client.base_url.join("get_expenses")?;
         let query = serde_qs::to_string(&request)?;
@@ -38,6 +48,20 @@ impl<'c> ExpensesSvc<'c> {
         Ok(response.expenses)
     }
 
+    /// Creates an expense. You may either split an expense equally (only with
+    /// `group_id` provided), or supply a list of shares.
+    ///
+    /// When splitting equally,
+    /// the authenticated user is assumed to be the payer.
+    ///
+    /// When providing a list of shares, each share must include `paid_share`
+    /// and `owed_share`, and must be identified by one of the following:
+    /// - `email`, `first_name`, and `last_name`
+    /// - `user_id`
+    ///
+    /// Note: The operation was successful only if `errors` is empty.
+    ///
+    /// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses/paths/~1create_expense/post)
     pub async fn create_expense(
         &self,
         request: CreateExpenseRequest,
@@ -63,6 +87,14 @@ impl<'c> ExpensesSvc<'c> {
         Ok(response.expenses)
     }
 
+    /// Updates an expense. Parameters are the same as in `create_expense`, but
+    /// you only need to include parameters that are changing from the previous
+    /// values. If any values is supplied for `users`, all shares for the
+    /// expense will be overwritten with the provided values.
+    ///
+    /// **Note:** The operation was successful only if `errors` is empty.
+    ///
+    /// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses/paths/~1update_expense~1{id}/post)
     pub async fn update_expense(
         &self,
         id: i64,
@@ -84,6 +116,9 @@ impl<'c> ExpensesSvc<'c> {
         Ok(response.expenses)
     }
 
+    /// Delete an expense.
+    ///
+    /// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses/paths/~1delete_expense~1{id}/post)
     pub async fn delete_expense(&self, id: i64) -> Result<(), anyhow::Error> {
         let url = self
             .client
@@ -103,7 +138,10 @@ impl<'c> ExpensesSvc<'c> {
         bail!("unknown error deleting expense: {}", id)
     }
 
-    pub async fn undelete_expense(&self, id: i64) -> Result<(), anyhow::Error> {
+    /// Restore an expense.
+    ///
+    /// [Splitwise API docs](https://dev.splitwise.com/#tag/expenses/paths/~1undelete_expense~1{id}/post)
+    pub async fn restore_expense(&self, id: i64) -> Result<(), anyhow::Error> {
         let url = self
             .client
             .base_url
@@ -132,7 +170,7 @@ mod integration_tests {
     use test_log::test;
 
     use super::*;
-    use crate::model::expenses::UserByShares;
+    use crate::model::expenses::UserShare;
 
     #[test(tokio::test)]
     async fn create_update_get_delete_undelete_list_expense_works() {
@@ -158,11 +196,11 @@ mod integration_tests {
 
         client.expenses().get_expense(id).await.unwrap();
         client.expenses().delete_expense(id).await.unwrap();
-        client.expenses().undelete_expense(id).await.unwrap();
+        client.expenses().restore_expense(id).await.unwrap();
         client.expenses().delete_expense(id).await.unwrap();
         client
             .expenses()
-            .get_expenses(GetExpensesRequest::default())
+            .list_expenses(ListExpensesRequest::default())
             .await
             .unwrap();
     }
@@ -187,11 +225,11 @@ mod integration_tests {
             cost: "1".to_string(),
             description: "Fake by-shares expense".to_string(),
             group_id: 0,
-            users: Some(vec![UserByShares {
+            users: Some(vec![UserShare {
                 user_id: Some(48903837),
                 owed_share: Some("1".to_string()),
                 paid_share: Some("1".to_string()),
-                ..UserByShares::default()
+                ..UserShare::default()
             }]),
             ..CreateExpenseRequest::default()
         };
