@@ -2,7 +2,10 @@ use std::collections::HashMap;
 
 use serde::{Deserialize, Serialize, Serializer};
 
-use crate::model::{users::User, Image};
+use crate::model::{
+    shared::{Debt, Image},
+    users::User,
+};
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub(crate) struct GroupsWrapper {
@@ -40,10 +43,10 @@ pub struct Group {
     pub members: Option<Vec<User>>,
 
     /// List of debts between users in the group.
-    pub original_debts: Option<Vec<GroupDebt>>,
+    pub original_debts: Option<Vec<Debt>>,
 
     /// List of simplified debts between users in the group.
-    pub simplified_debts: Option<Vec<GroupDebt>>,
+    pub simplified_debts: Option<Vec<Debt>>,
 
     /// Avatar image for the group.
     pub avatar: Option<Image>,
@@ -58,22 +61,6 @@ pub struct Group {
     pub invite_link: Option<String>,
 }
 
-/// Debt relationship between two users.
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-pub struct GroupDebt {
-    /// ID of the user who owes money.
-    pub from: Option<i64>,
-
-    /// ID of the user who paid money.
-    pub to: Option<i64>,
-
-    /// Decimal amount as a string with 2 decimal places.
-    pub amount: Option<String>,
-
-    /// A currency code. Must be in the list from `get_currencies`.
-    pub currency_code: Option<String>,
-}
-
 /// Splitwise `create_group` request.
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct GroupCreateRequest {
@@ -125,8 +112,11 @@ pub struct GroupDeleteResponse {
 /// Splitwise `restore_group` response.
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct GroupRestoreResponse {
+    /// Whether the request was successful.
     pub success: bool,
-    pub errors: Option<Vec<String>>, // TODO: handle error
+
+    /// Errors that occurred during the request.
+    pub errors: Option<Vec<String>>,
 }
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
@@ -141,9 +131,14 @@ pub(crate) struct GroupAddUserRequest {
 /// Splitwise `add_user_to_group` response.
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct GroupAddUserResponse {
+    /// Whether the request was successful.
     pub success: bool,
+
+    /// Users added to the group.
     pub user: Option<User>,
-    pub errors: Option<HashMap<String, Vec<String>>>, // TODO: handle error
+
+    /// Errors that occurred during the request.
+    pub errors: Option<HashMap<String, Vec<String>>>,
 }
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
@@ -155,8 +150,11 @@ pub(crate) struct GroupRemoveUserRequest {
 /// Splitwise `remove_user_from_group` response.
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct GroupRemoveUserResponse {
+    /// Whether the request was successful.
     pub success: bool,
-    pub errors: Option<Vec<String>>, // TODO: handle error
+
+    /// Errors that occurred during the request.
+    pub errors: Option<Vec<String>>,
 }
 
 fn serialize_option_vec_create_group_user<S: Serializer>(
